package com.loafle.crawler.snmp;

/**
 * Created by insanity on 17. 4. 7.
 */

import org.snmp4j.CommunityTarget;
import org.snmp4j.PDU;
import org.snmp4j.Snmp;
import org.snmp4j.TransportMapping;
import org.snmp4j.mp.SnmpConstants;
import org.snmp4j.smi.*;
import org.snmp4j.transport.DefaultUdpTransportMapping;
import org.snmp4j.util.DefaultPDUFactory;
import org.snmp4j.util.TreeUtils;

import java.util.Map;

public class SNMPv2c extends SNMP {

    private CommunityTarget getTarget(String addr, String port, String community) {
        UdpAddress address = new UdpAddress(addr + "/" + port);
        CommunityTarget target = new CommunityTarget();
        target.setCommunity(new OctetString(community));
        target.setAddress(address);
        target.setRetries(2);
        target.setTimeout(5000);
        target.setVersion(SnmpConstants.version2c);
        return target;
    }

    public Map<String, String> walk(String addr, String port, String community, String oidStr) throws Exception  {

        TransportMapping<? extends Address> transport = new DefaultUdpTransportMapping();
        Snmp snmp = new Snmp(transport);
        transport.listen();

        TreeUtils treeUtils = new TreeUtils(snmp, new DefaultPDUFactory());
        CommunityTarget target = getTarget(addr, port, community);

        return super.walk(snmp, oidStr, target, treeUtils);
    }


    public Map<String, String> get(String addr, String port, String community, String[] oids) throws Exception {

        TransportMapping<? extends Address> transport = new DefaultUdpTransportMapping();
        Snmp snmp = new Snmp(transport);
        transport.listen();

        CommunityTarget target = getTarget(addr, port, community);

        PDU pdu = new PDU();
        for (String oid : oids) {
            pdu.add(new VariableBinding(new OID(oid)));
        }
        pdu.setType(PDU.GET);
        pdu.setRequestID(new Integer32(1));

        return super.get(snmp, pdu, target);
    }

}